kdiagram.plot.relationship.plot\_residual\_relationship
=======================================================

.. currentmodule:: kdiagram.plot.relationship

.. autofunction:: plot_residual_relationship